form library

Classes

FormConfig<T extends FormConfigOption>
Base configuration for a form.
FormConfigOption
A form configuration option.
FormDescription
Description for a form config.
FormInputConfig
A text input configuration for a form.
FormRequirement<T extends FormConfigOption>
Represents a requirement for FormConfig.
FormSelectionConfig<T extends FormConfigOption>
A selection configuration for a form.
FormState
State for a Form component. This manages states for text input, focus and selection (single and multi).
ValidatingTextController
A TextEditingController that validates its text on every change and exposes the validation result via an error notifier.

Enums

BoolFormConfigOption
FormConfigOption that can either be enabled or disabled.