Checkbox class

A check box component

Constructors

Checkbox({Key? key, required String label, required bool value, bool focused = false})
const

Properties

focused bool
final
hashCode int
The hash code for this object.
no setterinherited
indicator String
no setter
key → Key?
finalinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value bool
final

Methods

build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
createElement() → StatelessElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited