FormDescription class

Description for a form config.

Constructors

FormDescription({required String label, double spacing = 1})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The description text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
Spacing between the description and the form input in the UI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited