FormInputConfig class abstract interface

A text input configuration for a form.

Implemented types

Properties

description FormDescription?
Optional description for this config.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
label String
UI visible label for this config.
no setterinherited
maxLines int
Max lines allowed for the text input in the UI.
no setter
requirements List<FormRequirement<FormConfigOption>>
Requirements for other related configs that must be satisfied for this config to be enabled.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixText String?
Optional suffix text displayed after the input value.
no setter
width double
Width of text input in the UI.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited