FormSelectionConfig<T extends FormConfigOption> class abstract interface

A selection configuration for a form.

Implemented types
Available extensions

Properties

defaultOptions Set<T>
The default config options.
no setter
description FormDescription?
Optional description for this config.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isBoolean bool

Available on FormSelectionConfig<FormConfigOption>, provided by the FormSelectionConfigExtension extension

Whether the config has boolean options.
no setter
label String
UI visible label for this config.
no setterinherited
multiSelect bool
Whether this config supports multi-select options.
no setter
options List<T>
Supported config options.
no setter
requirements List<FormRequirement<FormConfigOption>>
Requirements for other related configs that must be satisfied for this config to be enabled.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited