closeKey property
The key for dismissing this overlay. This is only displayed. Users should listen for the key event and to dismiss the overlay.
Implementation
final String closeKey;
The key for dismissing this overlay. This is only displayed. Users should listen for the key event and to dismiss the overlay.
final String closeKey;