paint method
Paint this render object and its children.
The canvas provides drawing operations and the offset is the position
in the parent's coordinate system where this render object should paint itself.
Subclasses should override this to paint themselves and call paint on their children with adjusted offsets.
Implementation
@override
void paint(TerminalCanvas canvas, Offset offset) {
super.paint(canvas, offset);
for (final child in children) {
final childParentData = child.parentData as FlexParentData;
child.paintWithContext(
canvas,
offset + childParentData.offset,
);
}
}