ServerpodTuiText class

A run of text with a single style with leading and trailing whitespaces removed for lines after the first line.

Constructors

ServerpodTuiText(String data, {Key? key, TextStyle? style, bool softWrap = true, TextOverflow overflow = TextOverflow.clip, TextAlign textAlign = TextAlign.left, int? maxLines})
const

Properties

child → Component?
finalinherited
data String
final
hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
maxLines int?
final
overflow → TextOverflow
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softWrap bool
final
style → TextStyle?
final
textAlign → TextAlign
final

Methods

createElement() → SingleChildRenderObjectElement
inherited
createRenderObject(BuildContext context) → RenderObject
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, covariant RenderText renderObject) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited