TabActivity enum

Activity state shown as a leading indicator on a tab.

Inheritance
Available extensions

Values

none → const TabActivity

No indicator.

running → const TabActivity

A dot in the theme's success color.

loading → const TabActivity

A spinner; animated when a SpinnerScope ancestor is present, otherwise a static fallback glyph.

stopped → const TabActivity

An empty circle in the theme's muted color.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TabActivity>
A constant List of the values in this enum, in order of their declaration.