components library
Classes
- BorderedBox
- A container with a rounded border and optional title.
- Button
- A keyboard-activated button with a highlighted activation character.
- ButtonBar
- A horizontal bar of Button widgets with consistent spacing.
- Checkbox
- A check box component
- CompletedOperationWidget
- Renders a completed tracked operation as a left-aligned log-style line with a trailing divider.
- Form
- A form component that renders text input, single select, boolean and multi-select options.
- FormBooleanConfiguration
- A boolean configuration rendered as a single checkbox.
- FormConfiguration
- Renders the appropriate configuration widget based on config's type.
- FormConfigurationLayout
- Renders a form configuration label and description wrapping child.
- FormInputConfiguration
-
A text input configuration rendered as a
TextField. - FormMultiSelectConfiguration
- A multi-select configuration rendered as checkboxes.
- FormSingleSelectConfiguration
- A single-select configuration rendered as radio buttons.
- HelpOverlay
- Help overlay showing all keybindings. Sizes to its content; scrolls if content exceeds the available terminal height.
- LogMessageWidget
- Renders a single structured log entry.
- Logo
- LogViewerWidget
- Renders structured log entries with active tracked operations stacked at the bottom.
- MultiScreenForm
- A multi screen form component that renders a screen for each config in state with a summary screen at the end.
- RadioButton
- A radio button component.
- RenderUnconstrainedBox
- RenderWrap
- Render object for wrap layouts.
- Shimmer
- A widget that applies an animated shimmer effect to its child.
- SpinnerIcon
- A spinner icon that uses the shared animation from SpinnerScope.
- SpinnerNotifier
- Notifier that broadcasts animation ticks to listeners.
- SpinnerScope
- Provides shared spinner animation state to descendants.
- TabBar
- A tab bar component.
- TextButton
- Tip
- Renders a tip.
- TrackedOperationWidget
- Renders an active tracked operation with spinner.
- UnconstrainedBox
-
Lets
childlay out at its natural size and reports that size up the tree, ignoring the parent's constraints. - Wrap
- Creates a wrap layout. By default, the wrap layout is horizontal.
Constants
-
runningFrames
→ const List<
String> - Braille frames that circle.
-
setupFrames
→ const List<
String> - Braille frames that fill upward.
-
teardownFrames
→ const List<
String> - Braille frames that fill downward.