FormInputConfiguration class
A text input configuration rendered as a TextField.
Constructors
- FormInputConfiguration({Key? key, required FormState state, required FormInputConfig config, required bool focused, required VoidCallback onTap, VoidCallback? onSubmit, VoidCallback? onArrowUp, VoidCallback? onArrowDown})
-
const
Properties
- config → FormInputConfig
-
final
- focused → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- onArrowDown → VoidCallback?
-
Callback for when
LogicalKey.arrowDownis received while text input is focused.final - onArrowUp → VoidCallback?
-
Callback for when
LogicalKey.arrowUpis received while text input is focused..final - onSubmit → VoidCallback?
-
Callback for when
LogicalKey.enteris received while text input is focused.final - onTap → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → FormState
-
final
Methods
-
build(
BuildContext context) → Component - Describes the part of the user interface represented by this component.
-
createElement(
) → StatelessElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited