FormRequirement<T extends FormConfigOption> class
Represents a requirement for FormConfig.
Constructors
-
FormRequirement({required FormConfig<
T> config, required Set<T> configOptions}) -
const
Properties
-
config
→ FormConfig<
T> -
The required config.
The selected option for this config
must be in configOptions for the requirement to be satisfied.
final
-
configOptions
→ Set<
T> -
The options for config that must be satisified.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited