A selection configuration for a form.
- Implemented types
-
- FormConfig<
T>
- FormConfig<
- Available extensions
Properties
-
defaultOptions
→ Set<
T> -
The default config options.
no setter
- description → FormDescription?
-
Optional description for this config.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBoolean → bool
-
Available on FormSelectionConfig<
Whether the config has boolean options.FormConfigOption> , provided by the FormSelectionConfigExtension extensionno setter - label → String
-
UI visible label for this config.
no setterinherited
- multiSelect → bool
-
Whether this config supports multi-select options.
no setter
-
options
→ List<
T> -
Supported config options.
no setter
-
requirements
→ List<
FormRequirement< FormConfigOption> > -
Requirements for other related configs that must be satisfied
for this config to be enabled.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited