FormSingleSelectConfiguration class
A single-select configuration rendered as radio buttons.
Constructors
-
FormSingleSelectConfiguration({Key? key, required FormState state, required FormSelectionConfig<
FormConfigOption> config, required bool focused, required VoidCallback rebuild}) -
const
Properties
-
config
→ FormSelectionConfig<
FormConfigOption> -
final
- focused → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- rebuild → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → FormState
-
final
Methods
-
build(
BuildContext context) → Component - Describes the part of the user interface represented by this component.
-
createElement(
) → StatelessElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited