HelpOverlay class
Help overlay showing all keybindings. Sizes to its content; scrolls if content exceeds the available terminal height.
Constructors
- HelpOverlay({Key? key, required HelpOverlayBindings bindings, required String closeKey, ScrollController? controller})
-
const
Properties
- bindings → HelpOverlayBindings
-
final
- closeKey → String
-
The key for dismissing this overlay.
This is only displayed. Users should listen for the key event
and to dismiss the overlay.
final
- controller → ScrollController?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< StatefulComponent> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited