LogViewerWidget class
Renders structured log entries with active tracked operations stacked at the bottom.
Constructors
- LogViewerWidget({Key? key, required TuiState state, required ScrollController scrollController, bool keyboardScrollable = false, Component? header})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Component?
-
final
- key → Key?
-
finalinherited
- keyboardScrollable → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController
-
final
- state → TuiState
-
final
Methods
-
build(
BuildContext context) → Component - Describes the part of the user interface represented by this component.
-
createElement(
) → StatelessElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited