onSelect method
Selects a focused button or form option. If a button is focused, navigates to the previous/next screen. Otherwise, if a form option is focused, selects it.
Implementation
@override
void onSelect() {
if (_focusOnButton) {
switch (_focusedButtonIndex) {
case 0:
previousScreen();
break;
case 1:
nextScreen();
break;
}
} else {
selectConfigOption();
}
}