RenderWrap class
Render object for wrap layouts.
Constructors
- RenderWrap({required Axis direction, required double spacing, required double runSpacing, required MainAxisAlignment mainAxisAlignment, required CrossAxisAlignment crossAxisAlignment})
Properties
-
children
→ List<
RenderObject> -
no setterinherited
- constraints → BoxConstraints
-
The box constraints most recently received from the parent.
no setterinherited
- crossAxisAlignment ↔ CrossAxisAlignment
-
getter/setter pair
- depth → int
-
Get the depth of this node in the tree (for sorting)
no setterinherited
- direction ↔ Axis
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSize → bool
-
Whether this render object has been laid out and has a size.
no setterinherited
- mainAxisAlignment ↔ MainAxisAlignment
-
getter/setter pair
- needsLayout → bool
-
Whether this render object needs layout.
no setterinherited
- needsPaint → bool
-
Whether this render object needs paint.
no setterinherited
- owner ↔ PipelineOwner?
-
The owner for this render object (null if unattached).
getter/setter pairinherited
- parent ↔ RenderObject?
-
The parent of this render object in the render tree.
getter/setter pairinherited
- parentData ↔ ParentData?
-
Data associated with this render object by its parent.
getter/setter pairinherited
- runSpacing ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionId ↔ Object?
-
Stable identity used by features that need to track render objects
across rebuilds (e.g., selection). Defaults to the render object instance.
getter/setter pairinherited
- size ↔ Size
-
The size of this render object as determined during layout.
getter/setter pairinherited
- spacing ↔ double
-
getter/setter pair
Methods
-
addChild(
RenderObject child) → void -
inherited
-
adoptChild(
RenderObject child) → void -
Adopt a child render object.
inherited
-
attach(
PipelineOwner owner) → void -
Attach this render object to the tree with the given owner.
inherited
-
detach(
) → void -
Detach this render object from the tree.
inherited
-
dispose(
) → void -
Dispose of any resources.
inherited
-
dropChild(
RenderObject child) → void -
Drop a child render object.
inherited
-
hitTest(
HitTestResult result, {required Offset position}) → bool -
Test whether a point hits this render object.
inherited
-
hitTestChildren(
HitTestResult result, {required Offset position}) → bool - Override this to test whether your children hit at the given position.
-
hitTestSelf(
Offset position) → bool -
Override this to test whether this render object hits at the given position.
inherited
-
insert(
RenderObject child, {RenderObject? after}) → void -
Insert a child at the correct position in the children list
inherited
-
invokeLayoutCallback<
T extends BoxConstraints> (void callback(T constraints)) → void -
Allows mutations to be made to this object's child list during layout.
inherited
-
layout(
BoxConstraints constraints, {bool parentUsesSize = false}) → void -
Compute the layout for this render object.
inherited
-
markNeedsLayout(
) → void -
Mark this render object as needing layout.
inherited
-
markNeedsPaint(
) → void -
Mark this render object as needing to be repainted.
inherited
-
move(
RenderObject child, {RenderObject? after}) → void -
Move a child to a new position in the children list
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
TerminalCanvas canvas, Offset offset) → void - Paint this render object and its children.
-
paintWithContext(
TerminalCanvas canvas, Offset offset) → void -
Internal paint method with error handling.
inherited
-
performLayout(
) → void - Do the actual work of computing this render object's layout.
-
removeAll(
) → void -
inherited
-
removeChild(
RenderObject child) → void -
inherited
-
setupParentData(
covariant RenderObject child) → void - Setup parent data for a child render object.
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
void visitor(RenderObject child)) → void -
Visit each child of this render object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited