SpinnerIcon class
A spinner icon that uses the shared animation from SpinnerScope.
If no SpinnerScope ancestor exists, displays a static '●' character. When frames is provided, maps the shared tick index to the custom frame sequence instead of using the default rotating braille pattern.
Constructors
-
SpinnerIcon({Color? color, List<
String> ? frames, Key? key}) -
const
Properties
- color → Color?
-
final
-
frames
→ List<
String> ? -
Custom frame sequence. When null, uses the shared SpinnerScope frames.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< SpinnerIcon> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited