Wrap class
Creates a wrap layout. By default, the wrap layout is horizontal.
Constructors
Properties
-
children
→ List<
Component> -
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- direction → Axis
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- runSpacing → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
final
Methods
-
createElement(
) → MultiChildRenderObjectElement -
createRenderObject(
BuildContext context) → RenderObject -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, covariant RenderWrap renderObject) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited